/* mpfr-glue.c generated by valac 0.36.5, the Vala compiler
 * generated from mpfr-glue.vala, do not modify */

/*
 * Copyright (C) 2016 Phillip Wood <phillip.wood@dunelm.org.uk>
 *
 * GNOME Calculator - mpfr-glue.vala
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Phillip Wood <phillip.wood@dunelm.org.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include "mpfr.h"

typedef struct _MPFRRealRef MPFRRealRef;

struct _MPFRRealRef {
	__mpfr_struct val;
};



void mpfr_real_ref_free (MPFRRealRef * self);
static void mpfr_real_ref_instance_init (MPFRRealRef * self);
MPFRRealRef* mpfr_real_ref_new (void);


MPFRRealRef* mpfr_real_ref_new (void) {
	MPFRRealRef* self;
	self = g_slice_new0 (MPFRRealRef);
	mpfr_real_ref_instance_init (self);
	return self;
}


static void mpfr_real_ref_instance_init (MPFRRealRef * self) {
}


void mpfr_real_ref_free (MPFRRealRef * self) {
	mpfr_clear (&self->val);
	g_slice_free (MPFRRealRef, self);
}



